## 股票周/月线行情(复权--每日更新)

接口：stk_week_month_adj

描述：股票周/月线行情(复权--每日更新)

限量：单次提取最大返回6000行数据，可通过股票代码和日期循环获取全部数据

权限：2000积分有权限

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | TS代码 |
| trade_date | str | N | 交易日期（格式：YYYYMMDD，下同） |
| start_date | str | N | 开始交易日期 |
| end_date | str | N | 结束交易日期 |
| freq | str | Y | 频率week周，month月 |

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| trade_date | str | Y | 交易日期（每周五或者月末日期） |
| end_date | str | Y | 计算截至日期 |
| freq | str | Y | 频率(周week,月month) |
| open | float | Y | (周/月)开盘价 |
| high | float | Y | (周/月)最高价 |
| low | float | Y | (周/月)最低价 |
| close | float | Y | (周/月)收盘价 |
| pre_close | float | Y | 上一(周/月)收盘价【除权价，前复权】 |
| open_qfq | float | Y | 前复权(周/月)开盘价 |
| high_qfq | float | Y | 前复权(周/月)最高价 |
| low_qfq | float | Y | 前复权(周/月)最低价 |
| close_qfq | float | Y | 前复权(周/月)收盘价 |
| open_hfq | float | Y | 后复权(周/月)开盘价 |
| high_hfq | float | Y | 后复权(周/月)最高价 |
| low_hfq | float | Y | 后复权(周/月)最低价 |
| close_hfq | float | Y | 后复权(周/月)收盘价 |
| vol | float | Y | (周/月)成交量 |
| amount | float | Y | (周/月)成交额 |
| change | float | Y | (周/月)涨跌额 |
| pct_chg | float | Y | (周/月)涨跌幅 【基于除权后的昨收计算的涨跌幅：（今收-除权昨收）/除权昨收 】 |

```python
pro = ts.pro_api()

df=pro.stk_week_month_adj(ts_code='000001.SZ',freq='week')
```

数据样例

```python
ts_code  trade_date  freq   open   high    low  close  pre_close  open_qfq  high_qfq  low_qfq  close_qfq  open_hfq  high_hfq  low_hfq  close_hfq         vol      amount  change  pct_chg
0     000001.SZ   20250117  week  11.25  11.59  11.08  11.45      11.30     11.25     11.59    11.08      11.45   1437.57   1481.02  1415.85    1463.13  4353954.80  4963695.53    0.15     0.01
```